**PFAID(portable file agnostic image data)** a small POC about making a lossless image format that can be even
used just like a file sha but for the image pixels, with this format it can be universal you can convert
a png and a jpg and if they are both the same image of for example a hill , they would make the same PFAID
regardless of the fileformat plus PFAID can be used for file conversion, and it's size is just a
bit smaller than png while being purely lossless
 
**NOTE: PFAID ONLY work in almost any operating system(\*1) which can support python 3.10 and above**

**\*1: PFAID wasn't tested on any operating system expect arch linux 
but mostly it can work on windows being that the library does not have any platform specific needs**

and this project is just a very small side project of mine

## Install

to install use the following command(note installing the library in this way
would install library requirements both main and optional):

<code>pip install pfaid</code>

## Contribute

if you have discovered a bug, or you want to change something just open a new issue
at [Issues](https://github.com/WeDu-official/pfaid/issues)

## Contact

you can contact us using this [email](mailto:fplu.the.founder@gmail.com)
,and you can be a part of our community by joining [our discord server](https://discord.gg/mnduzx6yUg)